==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property enabled Enables or disables the logging. Defaults to `false`.
 * @property logGroupName The CloudWatch group name for logging. This value is required if `enabled` is true.
 * @property logStreamName The CloudWatch log stream name for logging. This value is required if `enabled` is true.
 */
public data class FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs(
    public val enabled: Output<Boolean>? = null,
    public val logGroupName: Output<String>? = null,
    public val logStreamName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs> {
    override fun toJava():
        com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs =
        com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .logGroupName(logGroupName?.applyValue({ args0 -> args0 }))
            .logStreamName(logStreamName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs].
 */
@PulumiTagMarker
public class FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgsBuilder
internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var logGroupName: Output<String>? = null

    private var logStreamName: Output<String>? = null

    /**
     * @param value Enables or disables the logging. Defaults to `false`.
     */
    @JvmName("axbckgbjcneefsgn")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value The CloudWatch group name for logging. This value is required if `enabled` is true.
     */
    @JvmName("xpcwxpyhnxsfjoab")
    public suspend fun logGroupName(`value`: Output<String>) {
        this.logGroupName = value
    }

    /**
     * @param value The CloudWatch log stream name for logging. This value is required if `enabled` is true.
     */
    @JvmName("jtwbfqnwexexwejc")
    public suspend fun logStreamName(`value`: Output<String>) {
        this.logStreamName = value
    }

    /**
     * @param value Enables or disables the logging. Defaults to `false`.
     */
    @JvmName("hbmgucgdmsuavjaw")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value The CloudWatch group name for logging. This value is required if `enabled` is true.
     */
    @JvmName("erboyqjxxmocawfg")
    public suspend fun logGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logGroupName = mapped
    }

    /**
     * @param value The CloudWatch log stream name for logging. This value is required if `enabled` is true.
     */
    @JvmName("oxcnxciacswjdwud")
    public suspend fun logStreamName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logStreamName = mapped
    }

    internal fun build(): FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs =
        FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs(
            enabled = enabled,
            logGroupName = logGroupName,
            logStreamName = logStreamName,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property enabled Enables or disables the logging. Defaults to `false`.
 * @property logGroupName The CloudWatch group name for logging. This value is required if `enabled` is true.
 * @property logStreamName The CloudWatch log stream name for logging. This value is required if `enabled` is true.
 */
public data class FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs(
    public val enabled: Output<Boolean>? = null,
    public val logGroupName: Output<String>? = null,
    public val logStreamName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs =
        com.pulumi.aws.kinesis.inputs.FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .logGroupName(logGroupName?.applyValue({ args0 -> args0 }))
            .logStreamName(logStreamName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs].
 */
@PulumiTagMarker
public class FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgsBuilder
internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var logGroupName: Output<String>? = null

    private var logStreamName: Output<String>? = null

    /**
     * @param value Enables or disables the logging. Defaults to `false`.
     */
    @JvmName("woifvidwotwqwblv")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value The CloudWatch group name for logging. This value is required if `enabled` is true.
     */
    @JvmName("cppexudvqccclflv")
    public suspend fun logGroupName(`value`: Output<String>) {
        this.logGroupName = value
    }

    /**
     * @param value The CloudWatch log stream name for logging. This value is required if `enabled` is true.
     */
    @JvmName("wmbhjjhsahoesemv")
    public suspend fun logStreamName(`value`: Output<String>) {
        this.logStreamName = value
    }

    /**
     * @param value Enables or disables the logging. Defaults to `false`.
     */
    @JvmName("opfqcupwiffbextu")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value The CloudWatch group name for logging. This value is required if `enabled` is true.
     */
    @JvmName("qewtmnjofgakfqob")
    public suspend fun logGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logGroupName = mapped
    }

    /**
     * @param value The CloudWatch log stream name for logging. This value is required if `enabled` is true.
     */
    @JvmName("bfyepxtmgvohhnao")
    public suspend fun logStreamName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logStreamName = mapped
    }

    internal fun build(): FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs = FirehoseDeliveryStreamHttpEndpointConfigurationCloudwatchLoggingOptionsArgs(
        enabled = enabled,
        logGroupName = logGroupName,
        logStreamName = logStreamName,
    )
}
